# Automated Wei-Norman method

This library presents an automation of the Wei-Norman method for finding the time evolution operator of a system described by a Hamiltonian that is a sum of operators that form a closed Lie algebra.

Check our examples folder and our paper in: <https://arxiv.org/abs/2503.22061>
